@@ -321,6 +321,11 @@
 #define OP_GETCLIPBOARDSTRING	OPTYPE_NONE + 0x000135
 #define OP_SETCLIPBOARDIMAGE	OPTYPE_NONE + 0x000136
 #define OP_SETCLIPBOARDSTRING	OPTYPE_NONE + 0x000137
+#define OP_MKDIR				OPTYPE_NONE + 0x000138
+#define OP_RMDIR				OPTYPE_NONE + 0x000139
+#define OP_SPRITETEXT			OPTYPE_NONE + 0x00013a
+#define OP_PRINTAT				OPTYPE_NONE + 0x00013b
+
 
 #define OP_GOTO 				OPTYPE_LABEL + 0x000000
 #define OP_GOSUB 				OPTYPE_LABEL + 0x000001
@@ -333,7 +338,7 @@
 #define OP_CALLSUBROUTINE		OPTYPE_LABEL + 0x000008
 #define OP_ONERRORCALL   		OPTYPE_LABEL + 0x00000b
 #define OP_OFFERRORCATCH		OPTYPE_LABEL + 0x00000c
-
+#define OP_ONSTOPCALL   		OPTYPE_LABEL + 0x00000d
 
 
 #define OP_VAR_SET 				OPTYPE_VARIABLE + 0x000000
